==> openshift-model-4.13.3-sources.jar: io/fabric8/openshift/api/model/GitHubIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitHubIdentityProviderBuilder extends GitHubIdentityProviderFluentImpl<GitHubIdentityProviderBuilder> implements VisitableBuilder<GitHubIdentityProvider,GitHubIdentityProviderBuilder> {

    GitHubIdentityProviderFluent<?> fluent;
    Boolean validationEnabled;

    public GitHubIdentityProviderBuilder() { 
        this(true);
    }


    public GitHubIdentityProviderBuilder(Boolean validationEnabled) { 
        this(new GitHubIdentityProvider(), validationEnabled);
    }


    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent) { 
        this(fluent, true);
    }


    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new GitHubIdentityProvider(), validationEnabled);
    }


    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent,GitHubIdentityProvider instance) { 
        this(fluent, instance, true);
    }


    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent,GitHubIdentityProvider instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withCa(instance.getCa()); 
        fluent.withClientID(instance.getClientID()); 
        fluent.withClientSecret(instance.getClientSecret()); 
        fluent.withHostname(instance.getHostname()); 
        fluent.withOrganizations(instance.getOrganizations()); 
        fluent.withTeams(instance.getTeams()); 
        this.validationEnabled = validationEnabled; 
    }


    public GitHubIdentityProviderBuilder(GitHubIdentityProvider instance) { 
        this(instance,true);
    }


    public GitHubIdentityProviderBuilder(GitHubIdentityProvider instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withCa(instance.getCa()); 
        this.withClientID(instance.getClientID()); 
        this.withClientSecret(instance.getClientSecret()); 
        this.withHostname(instance.getHostname()); 
        this.withOrganizations(instance.getOrganizations()); 
        this.withTeams(instance.getTeams()); 
        this.validationEnabled = validationEnabled; 
    }


    public GitHubIdentityProvider build() {
        GitHubIdentityProvider buildable = new GitHubIdentityProvider(fluent.getCa(),fluent.getClientID(),fluent.getClientSecret(),fluent.getHostname(),fluent.getOrganizations(),fluent.getTeams());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitHubIdentityProviderBuilder that = (GitHubIdentityProviderBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: io/fabric8/openshift/api/model/GitHubIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitHubIdentityProviderBuilder extends GitHubIdentityProviderFluentImpl<GitHubIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<GitHubIdentityProvider,GitHubIdentityProviderBuilder> {

    GitHubIdentityProviderFluent<?> fluent;
    Boolean validationEnabled;

    public GitHubIdentityProviderBuilder() {
        this(true);
    }

    public GitHubIdentityProviderBuilder(Boolean validationEnabled) {
        this(new GitHubIdentityProvider(), validationEnabled);
    }

    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent) {
        this(fluent, true);
    }

    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new GitHubIdentityProvider(), validationEnabled);
    }

    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent,GitHubIdentityProvider instance) {
        this(fluent, instance, true);
    }

    public GitHubIdentityProviderBuilder(GitHubIdentityProviderFluent<?> fluent,GitHubIdentityProvider instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCa(instance.getCa()); 
        fluent.withClientID(instance.getClientID()); 
        fluent.withClientSecret(instance.getClientSecret()); 
        fluent.withHostname(instance.getHostname()); 
        fluent.withOrganizations(instance.getOrganizations()); 
        fluent.withTeams(instance.getTeams()); 
        this.validationEnabled = validationEnabled; 
    }

    public GitHubIdentityProviderBuilder(GitHubIdentityProvider instance) {
        this(instance,true);
    }

    public GitHubIdentityProviderBuilder(GitHubIdentityProvider instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCa(instance.getCa()); 
        this.withClientID(instance.getClientID()); 
        this.withClientSecret(instance.getClientSecret()); 
        this.withHostname(instance.getHostname()); 
        this.withOrganizations(instance.getOrganizations()); 
        this.withTeams(instance.getTeams()); 
        this.validationEnabled = validationEnabled; 
    }

    public GitHubIdentityProvider build() {
        GitHubIdentityProvider buildable = new GitHubIdentityProvider(fluent.getCa(),fluent.getClientID(),fluent.getClientSecret(),fluent.getHostname(),fluent.getOrganizations(),fluent.getTeams());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitHubIdentityProviderBuilder that = (GitHubIdentityProviderBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
